@@ -22,7 +22,7 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 # POSSIBILITY OF SUCH DAMAGE.
 package Graphics::GVG::SVG;
-$Graphics::GVG::SVG::VERSION = '0.2';
+$Graphics::GVG::SVG::VERSION = '0.3';
 # ABSTRACT: Convert GVG into SVG
 use strict;
 use warnings;
@@ -357,7 +357,7 @@ sub _draw_circle
         cx => $self->_coord_convert_x( $cmd->cx ),
         cy => $self->_coord_convert_y( $cmd->cy ),
         # Arbitrarily say the radius is according to the x coord.
-        r => $self->_coord_convert_x( $cmd->r ),
+        r => $self->_coord_convert_abs( $cmd->r, $self->width / 2 ),
         style => {
             $self->_default_style,
             stroke => $self->_color_to_style( $cmd->color ),
@@ -408,7 +408,13 @@ sub _coord_convert_x
 sub _coord_convert_y
 {
     my ($self, $coord) = @_;
-    return $self->_coord_convert( $coord, $self->height );
+    return $self->_coord_convert( -$coord, $self->height );
+}
+
+sub _coord_convert_abs
+{
+    my ($self, $coord, $total_size) = @_;
+    return $coord * $total_size;
 }
 
 sub _svg_coord_convert_x
